@@ -4,6 +4,7 @@ from pyparsing import (
     Empty,
     Group,
     Optional,
+    QuotedString,
     Suppress,
     Word,
     alphanums,
@@ -14,7 +15,9 @@ from pyparsing import (
 from .sections import GDSection, GDSectionHeader
 from .values import value
 
-key = Word(alphanums + "_/").setName("key")
+key = QuotedString('"', escChar="\\", multiline=False).setName("key") | Word(
+    alphanums + "_/"
+).setName("key")
 var = Word(alphanums + "_").setName("variable")
 attribute = Group(var + Suppress("=") + value)
 
